Documentation
¶
Overview ¶
Package model defines the model for the entire TUI.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
CurrentTarget target.Target
CurrentView target.View
Keys *keymap.KeyMap
Help *help.Model
Environments *environments.Model
EnvEditor *enveditor.Model
Requests *requests.Model
Editor *editor.Model
Response *response.Model
}
func (*Model) Init ¶
Init is the first function that will be called. It returns an optional initial command. To not perform an initial command return nil.
Click to show internal directories.
Click to hide internal directories.